@@ -1,3 +1,4 @@
+from django.core.urlresolvers import reverse
 from django.db import models
 
 
@@ -45,6 +46,9 @@ class Category(models.Model):
     def tags(self):
         return Tag.objects.filter(categories__in=[self]).order_by('title')
 
+    def get_absolute_url(self):
+        return reverse('category_object_list', kwargs={'category_slug': self.slug})
+
 class Tag(models.Model):
     """
     Tag model to be used for tagging content. Tags are to be used to describe
